# -*- coding: utf-8 -*-

import re

from django.conf import settings
from django.contrib import admin
import django.forms as forms

import basecontacts_gabnor.contacts.models as contacts_models
import basecontacts_gabnor.references.models as ref

from basecontacts_gabnor import logger


### ---------------------------------------------------------------------------
# Données et fonctions utilitaires
#


# Définition du widget utilisé pour les différentes adresse
# On le centralise ici pour qu'il soit partout pareil.
_widget_adresse = {
        'adresse': forms.Textarea(attrs={ 'rows': 3, 'cols': 40 }),
    }

### ---------------------------------------------------------------------------
# Form d'admin de modèles
#

class ContactAdminForm(forms.ModelForm):
    """
    Personnalisation du formulaire pour limiter l'adresse sur 4 lignes (pour
    simplifier la génération d'étiquettes) et affecter automatiquement les
    Cette classe n'est pas utilisée directement, mais est utilisable par
    héritage pour tous les modèles représentant un contact.
    """
    # La sous-classe Meta doit être définie par les classes filles pour
    # désigner le modèle qui s'applique. Meta n'est pas hérité.
    #
    #class Meta:
    #    model = ...
    #    widgets = _widget_adresse.copy()

    def clean_adresse(self):
        """
        Limite l'adresse à 4 lignes.
        """
        addr = re.sub("\s+$", "", self.cleaned_data["adresse"])
        if len(re.findall("\n", addr)) > 3:
            raise forms.ValidationError("L'adresse ne doit pas comporter"
                                        " plus de 4 lignes.")
        return addr

    def clean(self):
        """
        Affecte des valeurs par défaut au code postal et
        à la ville lorsque seule la commune est précisée.
        """
        commune = self.cleaned_data['commune']
        if commune:
            if not self.cleaned_data['code_postal']:
                self.cleaned_data['code_postal'] = commune.code_postal
            if not self.cleaned_data['ville']:
                self.cleaned_data['ville'] = commune.nom
        return self.cleaned_data


class StructureAdminForm(ContactAdminForm):
    """
    Réutilisation des méthodes de ContactAdminForm pour Structure.
    """
    class Meta:
        model = contacts_models.Structure
        widgets = _widget_adresse.copy()


class AgriculteurAdminForm(ContactAdminForm):
    """
    Personnalisation du formulaire pour limiter l'adresse sur 4 lignes (pour
    simplifier la génération d'étiquettes).
    """
    class Meta:
        model = contacts_models.Agriculteur
        widgets = _widget_adresse.copy()


class AgriculteurBioAdminForm(ContactAdminForm):
    """
    Personnalisation du formulaire pour limiter l'adresse sur 4 lignes (pour
    simplifier la génération d'étiquettes).
    """
    class Meta:
        model = contacts_models.AgriculteurBio
        widgets = _widget_adresse.copy()
    # dummy field to display the function with the same name
#    get_date_premiere_conversion = forms.CharField(max_length=100, initial='dummy')


class PersonneAdminForm(ContactAdminForm):
    """
    Personnalisation du formulaire pour limiter l'adresse sur 4 lignes (pour
    simplifier la génération d'étiquettes).
    """
    class Meta:
        model = contacts_models.Personne
        widgets = _widget_adresse.copy()



#
### ---------------------------------------------------------------------------
