# -*- coding: utf-8 -*-

from django.contrib import admin
import django.forms as forms
import django.db.models as dj_dbmodels
import basecontacts_gabnor.references.models as ref_models


class AdminPRA(admin.ModelAdmin):
    list_display = ('nom', 'code', 'grande_region', 'departement')
    list_filter = ('departement',)

class AdminCanton(admin.ModelAdmin):
    list_display = ('nom','numero','arrondissement')
    search_fields = ('nom',)
    list_filter = ('arrondissement',)

class AdminArrondissement(admin.ModelAdmin):
    list_display = ('nom','departement')
    list_filter = ('departement',)

class AdminCommune(admin.ModelAdmin):
    list_display = (
            'nom','code_commune','code_postal', 'arrondissement',
            'petite_region', 'zone', 'enjeu_eau'
            )
    filter_horizontal = ('cantons',)
    list_filter = ('enjeu_eau', 'zone', 'petite_region')
    search_fields = ('nom',)


class AdminDesignationObjet(admin.ModelAdmin):
    """
    Personnalisation de l'admin des tables basées sur DesignationObjet.
    """
    pass

class AdminEtiquette(AdminDesignationObjet):
    """
    Personnalisation de l'admin du modèle Etiquette.
    """
    list_display = ( 'designation', 'description' )


class AdminNomObjet(admin.ModelAdmin):
    """
    Personnalisation de l'admin des tables basées sur NomObjet.
    """
    pass


class AdminCulture(admin.ModelAdmin):
    """
    Personnalisation de l'admin du modèle Culture.
    """
    list_display = ( 'designation', 'categorie', 'indice_ordre' )
    list_editable = ( 'categorie', 'indice_ordre', )


def register_models(site):
    """
    Enregistrement des modèles dans un AdminSite passé en paramètre.
    """
    site.register(ref_models.Etiquette, AdminEtiquette)
    site.register(ref_models.Zone)
    site.register(ref_models.PetiteRegionAgricole, AdminPRA)
    site.register(ref_models.Canton, AdminCanton)
    site.register(ref_models.Arrondissement, AdminArrondissement)
    site.register(ref_models.Commune, AdminCommune)
    
    site.register(ref_models.CategorieStructure,
                  AdminDesignationObjet)
    site.register(ref_models.StatutCommercialisation,
                  AdminDesignationObjet)
    site.register(ref_models.TypeActivite,
                  AdminDesignationObjet)
    site.register(ref_models.AutreQualificatifExploitation,
                  AdminDesignationObjet)
    site.register(ref_models.Laiterie,
                  AdminNomObjet)
    site.register(ref_models.OrganismeDeCertification,
                  AdminNomObjet)
    site.register(ref_models.StatutStructure,
                  AdminDesignationObjet)
    site.register(ref_models.TypeService,
                  AdminDesignationObjet)
    site.register(ref_models.Culture,
                  AdminCulture)
    site.register(ref_models.ClientCulture,
                  AdminDesignationObjet)
    site.register(ref_models.Abattoir,
                  AdminNomObjet)
    site.register(ref_models.AcheteurOeufs,
                  AdminDesignationObjet)
    site.register(ref_models.Formation,
                  AdminDesignationObjet)
    site.register(ref_models.TypeFormation,
                  AdminDesignationObjet)

#register_models(admin.site)

